@@ -27,22 +27,33 @@ def cli(
     ),
     dev: bool = typer.Option(False, help="Enable development mode"),
 ):
-    log.init()
+    log.reset()
+    log.init(debug=dev)
+    log.silence("datafiles", allow_warning=True)
 
     scripts = {}
     for cls in Script.__subclasses__():
         script = cls()  # type: ignore
         scripts[script.name] = script
 
-    choices = list(scripts.keys())
+    choices = sorted(list(scripts.keys()))
     if "all" in names:
         log.info("Running all scripts")
         names = [k for k, v in scripts.items() if (not v.SKIP or duration < 60)]
         random.shuffle(names)
 
-    cli = Bullet(prompt="\nSelect a script to run:", bullet=" ● ", choices=choices)
+    cli = Bullet(
+        prompt="\nSelect a script to run:",
+        bullet=" ● ",
+        choices=choices,
+        return_index=True,
+    )
+    if pomace.settings.action > len(choices) - 1:
+        pomace.settings.action = 0
+    cli.pos = pomace.settings.action
     if not all(name in choices for name in names) or not names:
-        names = [cli.launch()]
+        value, pomace.settings.action = cli.launch()
+        names = [value]
         pomace.prompts.linebreak(force=True)
 
     try:
