@@ -10,7 +10,7 @@ class MyPillow(Script):
 
     URL = "https://www.mypillow.com/"
 
-    def run(self, page) -> pomace.Page:
+    def run(self, page: pomace.Page) -> pomace.Page:
         person = pomace.fake.person
 
         pomace.shared.client.clear_cookies()
@@ -32,7 +32,7 @@ class MyPillow(Script):
         page.fill_phone(person.phone)
         return page.click_get_mobile_alerts(wait=1)
 
-    def check(self, page) -> bool:
+    def check(self, page: pomace.Page) -> bool:
         success = "Thanks!" in page
         if success:
             page.click_continue_shopping(wait=0)
@@ -44,13 +44,22 @@ class FrankSpeech(Script):
     URL = "https://frankspeech.com/"
     SKIP = True
 
-    def run(self, page) -> pomace.Page:
-        log.info("Clearing cookies")
-        pomace.shared.client.clear_cookies()
-        page = pomace.visit(self.URL)
+    def run(self, page: pomace.Page) -> pomace.Page:
+        person = pomace.fake.person
 
-        page.fill_phone_number(pomace.fake.phone_number.replace("-", ""))
-        return page.click_submit()
+        page.click_profile(wait=0)
+        page = page.click_sign_up()
+        page.fill_phone_number(person.phone_number.replace("-", ""))
+        page.click_accept(wait=0)
+        page.fill_email_address(person.email_address)
+        page.fill_username(person.username)
 
-    def check(self, page) -> bool:
+        # TODO: Fix password fill by sending keys directly?
+        page.type_tab()
+        page.fill_password(person.password)
+        page.fill_confirm_password(person.password)
+
+        return page.click_create_new_account()
+
+    def check(self, page: pomace.Page) -> bool:
         return "home" in page.url
